# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/registry.ipynb (unless otherwise specified).

__all__ = ['Config', 'AttrDict', 'registry']

# Cell
from .markup import Config, AttrDict
from .thinc_parser.parser import registry
Config = Config
AttrDict = AttrDict
registry = registry